import {Component} from '@angular/core';
import {ActivatedRoute, NavigationStart, Router} from '@angular/router';

import {EnvProperties} from './openaireLibrary/utils/properties/env-properties';
import {MenuItem, RootMenuItem} from './openaireLibrary/sharedComponents/menu';
import {EnvironmentSpecificService} from './openaireLibrary/utils/properties/environment-specific.service';
import {CommunitiesService} from "./openaireLibrary/connect/communities/communities.service";
import {Session, User} from './openaireLibrary/login/utils/helper.class';
import {ConnectHelper} from './openaireLibrary/connect/connectHelper';
import {SubscribeService} from './openaireLibrary/utils/subscribe/subscribe.service';
import {HelperFunctions} from "./openaireLibrary/utils/HelperFunctions.class";
import {UserManagementService} from "./openaireLibrary/services/user-management.service";

@Component({
  //changeDetection: ChangeDetectionStrategy.Default,
  //encapsulation: ViewEncapsulation.Emulated,
  selector: 'app-root',
  styles: [`
  `],
  template: `
    <div [class]="(community)?(community.id +'App'):'connectApp'">
      <navbar *ngIf="properties && showMenu && !community && loginCheck" portal="monitor" [onlyTop]=false
              [userMenuItems]=userMenuItems [menuItems]=menuItems [user]="user"
              [showMenu]=showMenu [properties]="properties" [showHomeMenuItem]="true"></navbar>
      <navbar *ngIf="properties && showMenu  && community && loginCheck" portal="monitor" [onlyTop]=false [communityId]="community.id"
              [userMenuItems]=userMenuItems [menuItems]=menuItems [user]="user"
              [community]=community [showMenu]=showMenu [properties]="properties" [enableSearch]="true"
              [showHomeMenuItem]="true"></navbar>
      <div class="custom-main-content">
        <main>
          <router-outlet></router-outlet>
        </main>
      </div>
      <!--feedback *ngIf= "isClient && properties" portalName="Connect" [feedbackQuestionaire]=properties.feedbackQuestionaire></feedback-->
      <cookie-law *ngIf="isClient" position="bottom">
        OpenAIRE uses cookies in order to function properly.<br>
        Cookies are small pieces of data that websites store in your browser to allow us to give you the best browsing
        experience possible.
        By using the OpenAIRE portal you accept our use of cookies. <a
        href="//ec.europa.eu/ipg/basics/legal/cookies/index_en.htm" target="_blank"> Read more <span class="uk-icon">
            <svg width="20" height="20" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg" icon="chevron-right"
                 ratio="1"><polyline fill="none" stroke="#000" stroke-width="1.03"
                                     points="7 4 13 10 7 16"></polyline></svg>
            </span></a>
      </cookie-law>
      <bottom *ngIf="properties && isClient && showMenu && !community" [grantAdvance]="false"
              [properties]="properties"></bottom>
      <bottom *ngIf="properties && isClient  && showMenu && community" class="communityPanelBackground"
              [showSocialButtons]="true" [showMenuItems]="true" [grantAdvance]="false" [showOpenaire]="true"
              [communityId]="community.id" [menuItems]=bottomMenuItems [properties]="properties"></bottom>
    </div>
  `

})
export class AppComponent {
  isClient: boolean = false;

  userMenuItems: MenuItem[] = [];


  menuItems: RootMenuItem [] = [];
  bottomMenuItems: MenuItem[] = [];
  public community = null;
  properties: EnvProperties;
  showMenu: boolean = false;
  communities = null;
  subscriberOfCommunities = false;
  managerOfCommunities = false;
  user: User;
  loginCheck: boolean = false;

  //  community: {id:string, name:string, logoUrl:string};
  constructor(private  route: ActivatedRoute, private propertiesService: EnvironmentSpecificService,
              private _communitiesService: CommunitiesService, private _subscribeService: SubscribeService,
              private router: Router, private userManagementService: UserManagementService) {
    router.events.forEach((event) => {
      if (event instanceof NavigationStart) {
        HelperFunctions.scroll();
      }
    });
  }

  ngOnInit() {
    this.propertiesService.loadEnvironment()
      .then(es => {
        this.properties = this.propertiesService.envSpecific;
        var communityId: string = "";
        this._communitiesService.updateCommunities(this.properties, this.properties.communitiesAPI);
        this.userManagementService.getUserInfo(this.properties.userInfoUrl).subscribe( user => {
          this.user = user;
          this.loginCheck = true;
          if (this.properties.environment == "development") {
            this.showMenu = false;
            this.route.queryParams.subscribe(params => {
              communityId = (params['communityId']) ? params['communityId'] : '';
              this.buildMenu(communityId);
            })
          } else {
            this.showMenu = false;
            communityId = ConnectHelper.getCommunityFromDomain(this.properties.domain);
            this.buildMenu(communityId);
          }
          if (typeof document !== 'undefined') {
            try {
              this.isClient = true;
            } catch (e) {
            }
          }
        }, error => {
          console.log("App couldn't fetch properties");
          console.log(error);

        });
        });
  }

  public buildMenu(communityId: string) {
    let community = null;
    this.community = null;
    this._communitiesService.getCommunitiesState().subscribe(
      communities => {
        if (!communities || communities.length == 0 && communityId !== null && communityId !== '') {
          return;
        }
        for (var com of communities) {
          if ((communityId && communityId != "" && com.communityId == communityId
            && community != null) ||
            (
              !(communityId && communityId != "" && com.communityId == communityId)
              &&
              this.managerOfCommunities && this.subscriberOfCommunities)) {
            break;
          }
          if (this.user && com['status'] != "hidden") {
            if (Session.isCommunityCurator(this.user) || Session.isPortalAdministrator(this.user)) {
              this.managerOfCommunities = true;
            } else if (com.managers.indexOf(this.user.email) != -1) {
              this.managerOfCommunities = true;
            }
          }


          if (communityId && communityId != "" && com.communityId == communityId) {
            community = com;
            let isCommunityManager: boolean = false;
            if (Session.isCommunityCurator(this.user) || Session.isPortalAdministrator(this.user)) {
              isCommunityManager = true;
            } else if (this.user && com.managers.indexOf(this.user.email) != -1) {
              isCommunityManager = true;
            }
            this.community = {
              id: community.communityId,
              name: (community.shortTitle) ? community.shortTitle : community.title,
              logoUrl: community.logoUrl
            };
            this.menuItems = [];

            this.menuItems.push(
              {
                rootItem: new MenuItem("search", "Search", "", "/search/find", false, [], ["/search/find", "/search/find/publications", "/search/find/datasets", "/search/find/software", "/search/find/other", "/search/find/projects", "/search/find/dataproviders"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                items: [new MenuItem("", "Publications", "", "/search/find/publications", false, ["publication"], ["/search/find/publications"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Research Data", "", "/search/find/datasets", false, ["dataset"], ["/search/find/datasets"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Software", "", "/search/find/software", false, ["software"], ["/search/find/software"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Other Research Products", "", "/search/find/other", false, ["orp"], ["/search/find/other"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Projects", "", "/search/find/projects/", false, ["project"], ["/search/find/projects"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Content Providers", "", "/search/find/dataproviders", false, ["datasource"], ["/search/find/dataproviders"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                ]
              });

            this.menuItems.push({
              rootItem: new MenuItem("deposit", "Deposit", "", "/participate/deposit/learn-how", false, [], ["/participate/deposit/learn-how"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
              items: [
                /*
                new MenuItem("","Zenodo Communities","","/participate/share-zenodo",false,[],["/participate/share-zenodo"],this.properties.environment!="development"?{}:{communityId:community.communityId}),
                new MenuItem("","Publications","","/participate/deposit-publications",false,["publication"],["/participate/deposit-publications"],this.properties.environment!="development"?{}:{communityId:community.communityId}),
                new MenuItem("","Research Data","","/participate/deposit-datasets",false,["dataset"],["/participate/deposit-datasets"],this.properties.environment!="development"?{}:{communityId:community.communityId})
                */
              ]
            });
            this.menuItems.push(
              {
                rootItem: new MenuItem("link", "Link", "", "/participate/claim", false, [], ["/participate/claim"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                items: [
                  new MenuItem("", "Start linking", "", "/participate/claim", false, [], ["/participate/claim"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
                  new MenuItem("", "Learn more", this.properties.claimsInformationLink, "", false, [], [], {})
                ]
              });
            if (isCommunityManager) {
              this.menuItems.push(
                {
                  rootItem: new MenuItem("manage", "Manage", 'https://beta.admin.connect.openaire.eu/dashboard?communityId=' + community.communityId, "", false, [], [], {}),
                  items: []
                });
            }

          }

        }
        if (community == null) {
          this.menuItems = [];
          this.menuItems.push({
            rootItem: new MenuItem("about", "About", "", "/about/learn-how", false, [], null, {}),
            items: []
          });
          var myCommunities = [];
          /*if(this.managerOfCommunities){
            myCommunities.push( new MenuItem("","Managing communities","","/search/find/communities",false,[],[],{role:"%22manager%22"}))
          }
          if(Session.isLoggedIn()){
            this._subscribeService.getCommunitiesSubscribedTo(this.properties, Session.getUserEmail()).subscribe (
              pids => {
                if(pids.length > 0 ) {
                  myCommunities.push( new MenuItem("","Subscribed to communities","","/search/find/communities",false,[],[],{status:"%22subscribed%22"}))
                }
              },
              error => {
                console.error("Error fetching your subscribed communities")
              });
          }*/
          this.menuItems.push({
            rootItem: new MenuItem("communities", "Communities", "", "/search/find/communities", false, [], null, {}),
            items: []
          });
          this.menuItems.push({
            rootItem: new MenuItem("join", "Join", "", "/contact-us", false, [], null, {}),
            items: []
          });
          /*if(this.managerOfCommunities || this.subscriberOfCommunities){
            let myCommunitiesMenu =   new MenuItem("myCommunities","My Communities","","",false,[],[],{});
            myCommunitiesMenu.setMarkAsActive(false);
            this.menuItems.push({rootItem: myCommunitiesMenu, items: myCommunities});
          }*/


          this.bottomMenuItems = [
            new MenuItem("", "About", "https://beta.openaire.eu/project-factsheets", "", false, [], [], {}),
            new MenuItem("", "News - Events", "https://beta.openaire.eu/news-events", "", false, [], [], {}),
            new MenuItem("", "Blog", "https://blogs.openaire.eu/", "", false, [], [], {}),
            new MenuItem("", "Contact us", "https://beta.openaire.eu/contact-us", "", false, [], [], {})
          ];
          // if(this.properties.showContent){
          //   this.bottomMenuItems.push(new MenuItem("","Content Policy","","/content",false,[],[],{}));
          // }
          this.userMenuItems = [
            // new MenuItem("","My links","","/myclaims",false,[],["/myclaims"],(data['communityId'] && typeof document !== 'undefined' && ConnectHelper.isProduction(document.location.hostname))?{}:{communityId:data['communityId']}),
          ];
          if (Session.isPortalAdministrator(this.user)) {
            //((this.properties.environment == "beta") ? "https://beta.admin.connect.openaire.eu" : "https://admin.explore.openaire.eu") + "/dashboard?communityId=openaire"
            this.userMenuItems.push(new MenuItem("", "Manage Helptexts",
              ((this.properties.environment == "production") ? "https://admin.explore.openaire.eu" : "https://beta.admin.connect.openaire.eu") + "/dashboard?communityId=connect",
              "", false, [], [], {}))
          }
          /*if(this.managerOfCommunities){
            this.userMenuItems.push( new MenuItem("","Managing communities","","/search/find/communities",false,[],[],{role:"%22manager%22"}))
          }
          if(Session.isLoggedIn()){
            this._subscribeService.getCommunitiesSubscribedTo(this.properties, Session.getUserEmail()).subscribe (
              pids => {
                if(pids.length > 0 ) {
                  this.userMenuItems.push( new MenuItem("","Subscribed to communities","","/search/find/communities",false,[],[],{status:"%22subscribed%22"}))
                }
              },
              error => {
                console.error("Error fetching your subscribed communities")
              });
          }*/
          if (this.user) {
            this.userMenuItems.push(new MenuItem("my-communities", "My Communities", "",
              "/myCommunities", false, [], [], {}));
          }
        } else {
          this.bottomMenuItems = [
            // new MenuItem("","About","","/about",false,[],["/about"],this.properties.environment!="development"?{}:{communityId:community.communityId}),
            new MenuItem("", "Organizations", "", "/organizations", false, [], ["/organizations"], this.properties.environment != "development" ? {} : {communityId: community.communityId})
          ];
          if (this.properties.showContent) {
            this.bottomMenuItems.push(new MenuItem("", "Content Policy", "", "/content", false, [], [], {}));
          }
          this.userMenuItems = [ /*new MenuItem("","My profile","","",false,[],[],{}),*/
            new MenuItem("", "My links", "", "/myclaims", false, [], ["/myclaims"], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
            new MenuItem("", "Invite users", "", "/invite", false, [], [], this.properties.environment != "development" ? {} : {communityId: community.communityId}),
          ];
          if (this.managerOfCommunities) {
            this.userMenuItems.push(new MenuItem("", "Support", "https://openaire-connect.d4science.org/group/openaire-connect-gateway/explore?siteId=172366611", "", false, [], [], {}))
          }
        }
        this.showMenu = true;
      });
  }
}
