import {Component} from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import {Meta, Title} from '@angular/platform-browser';
import {EnvProperties} from '../openaireLibrary/utils/properties/env-properties';
import {CommunitiesService} from '../openaireLibrary/connect/communities/communities.service';
import {SubscribeService} from '../openaireLibrary/utils/subscribe/subscribe.service';
import {CommunityInfo} from '../openaireLibrary/connect/community/communityInfo';

import {PiwikService} from '../openaireLibrary/utils/piwik/piwik.service';
import {StringUtils} from '../openaireLibrary/utils/string-utils.class';

import {ErrorCodes} from '../openaireLibrary/utils/properties/errorCodes';
import {ErrorMessagesComponent} from '../openaireLibrary/utils/errorMessages.component';
import {HelperService} from "../openaireLibrary/utils/helper/helper.service";
import {SEOService} from "../openaireLibrary/sharedComponents/SEO/SEO.service";

@Component({
  selector: 'home',
  templateUrl: 'home.component.html',
})

export class HomeComponent {
  public piwiksub: any;

  public pageTitle = "OpenAIRE | Monitor";
  public pageContents = null;
  public divContents = null;
  public status: number;
  public loading: boolean = true;
  public subscriberErrorMessage: string = "";
  public errorCodes: ErrorCodes;
  private errorMessages: ErrorMessagesComponent;

  properties: EnvProperties;
  public keyword: string = "";
  public type: string = "all";

  constructor(
    private route: ActivatedRoute,
    private _router: Router,
    private _meta: Meta,
    private _title: Title,
    private _piwikService: PiwikService,
    private helper: HelperService,
    private seoService: SEOService) {

    var description = "OpenAIRE - Monitor, monitor dashboard, funder, statistics, ";
    var title = "OpenAIRE - Monitor";

    this._meta.updateTag({content: description}, "name='description'");
    this._meta.updateTag({content: description}, "property='og:description'");
    this._meta.updateTag({content: title}, "property='og:title'");
    this._title.setTitle(title);

    this.errorCodes = new ErrorCodes();
    this.errorMessages = new ErrorMessagesComponent();
    this.status = this.errorCodes.LOADING;
  }

  public ngOnInit() {
    this.route.data
      .subscribe((data: { envSpecific: EnvProperties }) => {
        this.properties = data.envSpecific;
        var url = data.envSpecific.baseLink + this._router.url;
        this.seoService.createLinkForCanonicalURL(url, false);
        this._meta.updateTag({content: url}, "property='og:url'");
        if (this.properties.enablePiwikTrack && (typeof document !== 'undefined')) {
          this.piwiksub = this._piwikService.trackView(this.properties, "OpenAIRE Monitor", this.properties.piwikSiteId).subscribe();
        }
        //this.getDivContents();
        this.getPageContents();
      });
  }

  private getPageContents() {
    this.helper.getPageHelpContents(this._router.url, this.properties, 'monitor').subscribe(contents => {
      this.pageContents = contents;
    })
  }

  private getDivContents() {
    this.helper.getDivHelpContents(this._router.url, this.properties, 'monitor').subscribe(contents => {
      this.divContents = contents;
    })
  }

  public quote(param: string): string {
    return StringUtils.quote(param);
  }

  public ngOnDestroy() {
    if (this.piwiksub) {
      this.piwiksub.unsubscribe();
    }
  }

  private handleError(message: string, error): number {
    var code = "";
    if (!error.status) {
      var error = error.json();
      code = error.code;
    } else {
      code = error.status;
    }

    console.error("Communities (component): " + message, error);

    return this.errorMessages.getErrorCode(code);
  }
}
